@@ -1,3 +1,5 @@
+import warnings
+
 import numpy as np
 
 from asreviewcontrib.visualization.plot_base import PlotBase
@@ -5,7 +7,8 @@ from asreviewcontrib.visualization.plot_base import PlotBase
 
 class PlotInclusions(PlotBase):
     def __init__(self, analyses, result_format="percentage", thick=None):
-        """
+        """Class for the Inclusions plot.
+
         Plot the number of queries that turned out to be included
         in the final review.
         """
@@ -31,7 +34,7 @@ class PlotInclusions(PlotBase):
             n_after_init = len(analysis.labels) - n_initial
             max_len = max(max_len, n_after_init)
 
-            self.col[data_key] = "C"+str((len(self.analyses)-1-i) % 10)
+            self.col[data_key] = "C" + str((len(self.analyses) - 1 - i) % 10)
             col = self.col[data_key]
 
             if self.thick[data_key]:
@@ -56,8 +59,20 @@ class PlotInclusions(PlotBase):
             self.ax.set_ylabel("% Inclusions found")
         self.fig.tight_layout()
 
-    def add_WSS(self, data_key, value=95, text_at=None, add_value=False,
-                alpha=0.8, text_col="white", add_text=True, **kwargs):
+    def add_WSS(self, *args, **kwargs):  # noqa
+        warnings.warn("add_WSS is deprecated, use add_wss instead",
+                      DeprecationWarning)
+        self.add_wss(*args, **kwargs)
+
+    def add_wss(self,
+                data_key,
+                value=95,
+                text_at=None,
+                add_value=False,
+                alpha=0.8,
+                text_col="white",
+                add_text=True,
+                **kwargs):
         analysis = self.analyses[data_key]
         col = self.col[data_key]
 
@@ -65,45 +80,59 @@ class PlotInclusions(PlotBase):
             return
 
         text = f"WSS@{value}%"
-        WSS_val, WSS_x, WSS_y = analysis.wss(
-            value, x_format=self.result_format, **kwargs)
-        if WSS_x is None or WSS_y is None:
+        wss_val, wss_x, wss_y = analysis.wss(value,
+                                             x_format=self.result_format,
+                                             **kwargs)
+        if wss_x is None or wss_y is None:
             return
 
         if add_value:
-            text += r"$\approx" + f" {round(WSS_val, 2)}" + r"\%$"
+            text += r"$\approx" + f" {round(wss_val, 2)}" + r"\%$"
 
         if text_at is None:
-            text_at = (WSS_x[0] + self.box_dist, (WSS_y[0] + WSS_y[1])/2)
+            text_at = (wss_x[0] + self.box_dist, (wss_y[0] + wss_y[1]) / 2)
 
-        self.ax.plot(WSS_x, WSS_y, color=col, ls="--")
-        self.ax.plot(WSS_x, (0, WSS_y[0]), color=col, ls=":")
+        self.ax.plot(wss_x, wss_y, color=col, ls="--")
+        self.ax.plot(wss_x, (0, wss_y[0]), color=col, ls=":")
         bbox = dict(boxstyle='round', facecolor=col, alpha=alpha)
         if add_text:
             self.ax.text(*text_at, text, color=text_col, bbox=bbox)
 
-    def add_RRF(self, data_key, value=10, text_at=None, add_value=False,
-                alpha=0.8, text_col="white", add_text=True, **kwargs):
+    def add_RRF(self, *args, **kwargs):  # noqa
+        warnings.warn("add_RRF is deprecated, use add_rrf instead",
+                      DeprecationWarning)
+        self.add_rrf(*args, **kwargs)
+
+    def add_rrf(self,
+                data_key,
+                value=10,
+                text_at=None,
+                add_value=False,
+                alpha=0.8,
+                text_col="white",
+                add_text=True,
+                **kwargs):
         analysis = self.analyses[data_key]
         col = self.col[data_key]
         if value is None:
             return
 
-        RRF_val, RRF_x, RRF_y = analysis.rrf(
-            value, x_format=self.result_format, **kwargs)
-        if RRF_x is None or RRF_y is None:
+        rrf_val, rrf_x, rrf_y = analysis.rrf(value,
+                                             x_format=self.result_format,
+                                             **kwargs)
+        if rrf_x is None or rrf_y is None:
             return
 
         text = f"RRF@{value}%"
         if add_value:
-            text += r"$\approx" + f" {round(RRF_val, 2)}" + r"\%$"
+            text += r"$\approx" + f" {round(rrf_val, 2)}" + r"\%$"
 
-        RRF_x = 0, RRF_x[0]
-        RRF_y = RRF_y[1], RRF_y[1]
+        rrf_x = 0, rrf_x[0]
+        rrf_y = rrf_y[1], rrf_y[1]
         if text_at is None:
-            text_at = (RRF_x[0] + self.box_dist, RRF_y[0] + self.box_dist + 2)
+            text_at = (rrf_x[0] + self.box_dist, rrf_y[0] + self.box_dist + 2)
 
-        self.ax.plot(RRF_x, RRF_y, color=col, ls="--")
+        self.ax.plot(rrf_x, rrf_y, color=col, ls="--")
         bbox = dict(boxstyle='round', facecolor=col, alpha=alpha)
         if add_text:
             self.ax.text(*text_at, text, color=text_col, bbox=bbox)
@@ -115,8 +144,8 @@ class PlotInclusions(PlotBase):
             xlim = self.ax.get_xlim()
             ylim = self.ax.get_ylim()
             text_at = (
-                np.average(xlim) - 0.07 * (xlim[1]-xlim[0]),
-                np.average(xlim) + 0.07 * (ylim[1]-ylim[0]),
+                np.average(xlim) - 0.07 * (xlim[1] - xlim[0]),
+                np.average(ylim) + 0.07 * (ylim[1] - ylim[0]),
             )
 
         bbox = dict(boxstyle='round', facecolor='0.65')
@@ -125,4 +154,12 @@ class PlotInclusions(PlotBase):
         xlim = [max(x, 0) for x in xlim]
         if self.result_format == "percentage":
             xlim = [min(x, 100) for x in xlim]
-        self.ax.plot(xlim, xlim, color='black', ls="--")
+            y_vals = xlim
+        else:
+            analysis = self.analyses[list(self.analyses)[0]]
+            n_labels = len(analysis.labels)
+            n_initial = analysis.inc_found[False]["n_initial"]
+            max_y = analysis.inc_found[False]["inc_after_init"]
+            label_after_init = n_labels - n_initial
+            y_vals = max_y * np.array(xlim) / label_after_init
+        self.ax.plot(xlim, y_vals, color='black', ls="--")
