@@ -1,4 +1,20 @@
+# Copyright 2020 The ASReview Authors. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 def inclusion_plot(plot, output=None, **kwargs):
+    """Make an inclusion plot."""
     all_files = all(plot.is_file.values())
 
     inc_plot = plot.new("inclusion", **kwargs)
@@ -6,9 +22,9 @@ def inclusion_plot(plot, output=None, **kwargs):
 
     for key in list(plot.analyses):
         if all_files or not plot.is_file[key]:
-            inc_plot.add_WSS(key, 95)
-            inc_plot.add_WSS(key, 100)
-            inc_plot.add_RRF(key, 5)
+            inc_plot.add_wss(key, 95)
+            inc_plot.add_wss(key, 100)
+            inc_plot.add_rrf(key, 5)
     inc_plot.add_random()
     inc_plot.set_legend()
     if output is None:
@@ -19,6 +35,7 @@ def inclusion_plot(plot, output=None, **kwargs):
 
 
 def progression_plot(plot, output=None, **kwargs):
+    """Make a progression plot."""
     prog_plot = plot.new("progression", **kwargs)
     prog_plot.set_grid()
     prog_plot.set_legend()
@@ -30,6 +47,7 @@ def progression_plot(plot, output=None, **kwargs):
 
 
 def discovery_plot(plot, output=None, **kwargs):
+    """Make a discovery plot."""
     disc_plot = plot.new("discovery", **kwargs)
     disc_plot.set_legend()
     if output is None:
@@ -40,6 +58,7 @@ def discovery_plot(plot, output=None, **kwargs):
 
 
 def limit_plot(plot, output=None, **kwargs):
+    """Make a limit plot."""
     limit_plot = plot.new("limit", **kwargs)
     limit_plot.set_legend()
     limit_plot.set_grid()
